@@ -21,7 +21,7 @@ class File:
         self.__description__ = '文件相关， 包括读文件，写文件， 下载文件'
         self.base_dir = base_dir
 
-    def read(self, file_name, sheet_name='', read_type='r', dict_name='', to_json=True, table_sheet=True, **kwargs):
+    def read(self, file_name, sheet_name='Sheet1', read_type='r', dict_name='', to_json=True, table_sheet=True, **kwargs):
         file_type = file_name.split('.')[-1]
         url = os.path.join(self.base_dir, dict_name, file_name)
         if os.path.exists(url) is False:
